Add string support to nvramtool.

To add a string to your cmos.layout, you need to specify type 's':

#start     len       type    unused   name
416        512       s       0        boot_devices

With this patch you can do

$ nvramtool -w boot_devices="(hd0,0);(hd2,1);(hd3)"

And FILO will attempt to load a menu.lst from any of these devices in that order.

The patch is not exactly pretty, but a cleaner solution might have resulted in
a complete rewrite of the tool, which I did not want.

Signed-off-by: Stefan Reinauer <stepan@coresystems.de>


Index: util/nvramtool/input_file.c
===================================================================
--- util/nvramtool/input_file.c	(revision 364)
+++ util/nvramtool/input_file.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * input_file.c
- * $Id: input_file.c 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
@@ -137,6 +136,7 @@
 
       item->bit = e->bit;
       item->length = e->length;
+      item->config = e->config;
       item->value = try_prepare_cmos_write(e, value);
 
       /* Append write operation to pending write list. */
@@ -162,9 +162,13 @@
    set_iopl(3);
 
    while (list != NULL)
-    { item = list;
+    { cmos_entry_t e;
+      item = list;
+      e.bit = item->bit;
+      e.length = item->length;
+      e.config = item->config;
       list = item->next;
-      cmos_write(item->bit, item->length, item->value);
+      cmos_write(&e, item->value);
       free(item);
     }
 
Index: util/nvramtool/nvramtool.1
===================================================================
--- util/nvramtool/nvramtool.1	(revision 364)
+++ util/nvramtool/nvramtool.1	(working copy)
@@ -1,6 +1,5 @@
 .\"***************************************************************************\
 .\" nvramtool.1
-.\" $Id: nvramtool.1 3123 2008-03-01 19:07:46Z uwe $
 .\"***************************************************************************
 .\"  Copyright (C) 2002, 2003 The Regents of the University of California.
 .\"  Produced at the Lawrence Livermore National Laboratory.
@@ -28,7 +27,7 @@
 .\"  with this program; if not, write to the Free Software Foundation, Inc.,
 .\"  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 .\"***************************************************************************/
-.TH NVRAMTOOL 1 "January 2008" Linux
+.TH NVRAMTOOL 1 "September 2008" Linux
 .SH NAME
 nvramtool \- read/write coreboot-related information
 .SH SYNOPSIS
@@ -252,4 +251,4 @@
 .SH AUTHORS
 David S. Peterson <dsp@llnl.gov> <dave_peterson@pobox.com>
 .br
-Stefan Reinauer <stepan@openbios.org>
+Stefan Reinauer <stepan@coresystems.de>
Index: util/nvramtool/ip_checksum.h
===================================================================
--- util/nvramtool/ip_checksum.h	(revision 364)
+++ util/nvramtool/ip_checksum.h	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * ip_checksum.h
- * $Id: ip_checksum.h 3075 2008-01-25 15:08:37Z uwe $
 \*****************************************************************************/
 
 #ifndef IP_CHECKSUM_H
Index: util/nvramtool/input_file.h
===================================================================
--- util/nvramtool/input_file.h	(revision 364)
+++ util/nvramtool/input_file.h	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * input_file.h
- * $Id: input_file.h 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
@@ -33,6 +32,7 @@
 #define INPUT_FILE_H
 
 #include "common.h"
+#include "layout.h"
 
 typedef struct cmos_write_t cmos_write_t;
 
@@ -44,6 +44,7 @@
 struct cmos_write_t
  { unsigned bit;
    unsigned length;
+   cmos_entry_config_t config;
    unsigned long long value;
    cmos_write_t *next;
  };
Index: util/nvramtool/lbtable.c
===================================================================
--- util/nvramtool/lbtable.c	(revision 364)
+++ util/nvramtool/lbtable.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * lbtable.c
- * $Id: lbtable.c 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
@@ -30,6 +29,7 @@
  *  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 \*****************************************************************************/
 
+#include <string.h>
 #include <sys/mman.h>
 #include "common.h"
 #include "coreboot_tables.h"
@@ -556,7 +556,7 @@
    for (p = first_cmos_table_enum(); p != NULL; p = next_cmos_table_enum(p))
     { cmos_enum.config_id = p->config_id;
       cmos_enum.value = p->value;
-      strncpy(cmos_enum.text, p->text, CMOS_MAX_TEXT_LENGTH);
+      strncpy(cmos_enum.text, (char *)p->text, CMOS_MAX_TEXT_LENGTH);
       cmos_enum.text[CMOS_MAX_TEXT_LENGTH] = '\0';
       try_add_cmos_table_enum(&cmos_enum);
     }
@@ -581,6 +581,10 @@
             cmos_entry.config = CMOS_ENTRY_RESERVED;
             break;
 
+         case 's':
+            cmos_entry.config = CMOS_ENTRY_STRING;
+            break;
+
          default:
             fprintf(stderr,
                     "%s: Entry in CMOS option table has unknown config "
@@ -589,7 +593,7 @@
        }
 
       cmos_entry.config_id = q->config_id;
-      strncpy(cmos_entry.name, q->name, CMOS_MAX_NAME_LENGTH);
+      strncpy(cmos_entry.name, (char *)q->name, CMOS_MAX_NAME_LENGTH);
       cmos_entry.name[CMOS_MAX_NAME_LENGTH] = '\0';
       try_add_cmos_table_entry(&cmos_entry);
     }
Index: util/nvramtool/ChangeLog
===================================================================
--- util/nvramtool/ChangeLog	(revision 364)
+++ util/nvramtool/ChangeLog	(working copy)
@@ -1,3 +1,11 @@
+Tue Sep 23 19:14:27 CEST 2008  Stefan Reinauer (stepan@coresystems.de)
+
+	Version 2.1
+
+	* Fix a number of off by one errors when accessing arrays
+
+	* Add support for reading/writing strings from/to CMOS.
+
 Mon Jan 23 16:00:00 PST 2006  David S. Peterson (dsp@llnl.gov)
 
 	Version 2.0.1
Index: util/nvramtool/lbtable.h
===================================================================
--- util/nvramtool/lbtable.h	(revision 364)
+++ util/nvramtool/lbtable.h	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * lbtable.h
- * $Id: lbtable.h 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
Index: util/nvramtool/cmos_lowlevel.c
===================================================================
--- util/nvramtool/cmos_lowlevel.c	(revision 364)
+++ util/nvramtool/cmos_lowlevel.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * cmos_lowlevel.c
- * $Id: cmos_lowlevel.c 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
@@ -70,7 +69,7 @@
  ****************************************************************************/
 static inline void put_bits (unsigned char value, unsigned bit,
                              unsigned nr_bits, unsigned long long *result)
- { *result += (value & ((unsigned char) ((1 << nr_bits) - 1))) << bit; }
+ { *result += ((unsigned long long)(value & ((unsigned char) ((1 << nr_bits) - 1)))) << bit; }
 
 /****************************************************************************
  * cmos_read
@@ -79,22 +78,40 @@
  * and return this value.  The I/O privilege level of the currently executing
  * process must be set appropriately.
  ****************************************************************************/
-unsigned long long cmos_read (unsigned bit, unsigned length)
+unsigned long long cmos_read (const cmos_entry_t *e)
  { cmos_bit_op_location_t where;
+   unsigned bit = e->bit, length=e->length;
    unsigned next_bit, bits_left, nr_bits;
-   unsigned long long result;
+   unsigned long long result = 0;
    unsigned char value;
 
-   assert(!verify_cmos_op(bit, length));
+   assert(!verify_cmos_op(bit, length, e->config));
    result = 0;
 
-   for (next_bit = 0, bits_left = length;
-        bits_left;
-        next_bit += nr_bits, bits_left -= nr_bits)
-    { nr_bits = cmos_bit_op_strategy(bit + next_bit, bits_left, &where);
-      value = cmos_read_bits(&where, nr_bits);
-      put_bits(value, next_bit, nr_bits, &result);
+   if (e->config == CMOS_ENTRY_STRING)
+    { char *newstring = malloc((length+7)/8);
+      unsigned usize = (8 * sizeof(unsigned long long));
+
+      if(!newstring) { out_of_memory(); }
+
+      for (next_bit = 0, bits_left = length;
+           bits_left;
+           next_bit += nr_bits, bits_left -= nr_bits)
+       { nr_bits = cmos_bit_op_strategy(bit + next_bit, bits_left>usize?usize:bits_left, &where);
+         value = cmos_read_bits(&where, nr_bits);
+         put_bits(value, next_bit % usize, nr_bits, &((unsigned long long *)newstring)[next_bit/usize]);
+	 result = (unsigned long)newstring;
+       }
     }
+   else
+    { for (next_bit = 0, bits_left = length;
+           bits_left;
+           next_bit += nr_bits, bits_left -= nr_bits)
+       { nr_bits = cmos_bit_op_strategy(bit + next_bit, bits_left, &where);
+         value = cmos_read_bits(&where, nr_bits);
+         put_bits(value, next_bit, nr_bits, &result);
+       }
+    }
 
    return result;
  }
@@ -106,18 +123,33 @@
  * The I/O privilege level of the currently executing process must be set
  * appropriately.
  ****************************************************************************/
-void cmos_write (unsigned bit, unsigned length, unsigned long long value)
+void cmos_write (const cmos_entry_t *e, unsigned long long value)
  { cmos_bit_op_location_t where;
+   unsigned bit = e->bit, length=e->length;
    unsigned next_bit, bits_left, nr_bits;
 
-   assert(!verify_cmos_op(bit, length));
+   assert(!verify_cmos_op(bit, length, e->config));
 
-   for (next_bit = 0, bits_left = length;
-        bits_left;
-        next_bit += nr_bits, bits_left -= nr_bits)
-    { nr_bits = cmos_bit_op_strategy(bit + next_bit, bits_left, &where);
-      cmos_write_bits(&where, nr_bits, get_bits(value, next_bit, nr_bits));
+   if (e->config == CMOS_ENTRY_STRING) 
+    { unsigned long long *data = (unsigned long long *)(unsigned long)value;
+      unsigned usize = (8 * sizeof(unsigned long long));
+
+      for (next_bit = 0, bits_left = length;
+           bits_left;
+           next_bit += nr_bits, bits_left -= nr_bits)
+       { nr_bits = cmos_bit_op_strategy(bit + next_bit, bits_left>usize?usize:bits_left, &where);
+         value = data[next_bit/usize];
+         cmos_write_bits(&where, nr_bits, get_bits(value, next_bit % usize, nr_bits));
+       }
     }
+   else
+    { for (next_bit = 0, bits_left = length;
+           bits_left;
+           next_bit += nr_bits, bits_left -= nr_bits)
+       { nr_bits = cmos_bit_op_strategy(bit + next_bit, bits_left, &where);
+         cmos_write_bits(&where, nr_bits, get_bits(value, next_bit, nr_bits));
+       }
+    }
  }
 
 /****************************************************************************
@@ -236,13 +268,16 @@
  * wish to read or write.  Perform sanity checking on 'bit' and 'length'.  If
  * no problems were encountered, return OK.  Else return an error code.
  ****************************************************************************/
-int verify_cmos_op (unsigned bit, unsigned length)
+int verify_cmos_op (unsigned bit, unsigned length, cmos_entry_config_t config)
  { if ((bit >= (8 * CMOS_SIZE)) || ((bit + length) > (8 * CMOS_SIZE)))
       return CMOS_AREA_OUT_OF_RANGE;
 
    if (bit < (8 * CMOS_RTC_AREA_SIZE))
       return CMOS_AREA_OVERLAPS_RTC;
 
+   if (config == CMOS_ENTRY_STRING)
+      return OK;
+
    if (length > (8 * sizeof(unsigned long long)))
       return CMOS_AREA_TOO_WIDE;
 
Index: util/nvramtool/hexdump.c
===================================================================
--- util/nvramtool/hexdump.c	(revision 364)
+++ util/nvramtool/hexdump.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * hexdump.c
- * $Id: hexdump.c 3075 2008-01-25 15:08:37Z uwe $
 \*****************************************************************************/
 
 #include "hexdump.h"
Index: util/nvramtool/reg_expr.c
===================================================================
--- util/nvramtool/reg_expr.c	(revision 364)
+++ util/nvramtool/reg_expr.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * reg_expr.c
- * $Id: reg_expr.c 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
Index: util/nvramtool/layout_file.c
===================================================================
--- util/nvramtool/layout_file.c	(revision 364)
+++ util/nvramtool/layout_file.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * layout_file.c
- * $Id: layout_file.c 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
@@ -551,6 +550,10 @@
          cmos_entry->config = CMOS_ENTRY_HEX;
          break;
 
+      case 's':
+	 cmos_entry->config = CMOS_ENTRY_STRING;
+	 break;
+
       case 'r':
          cmos_entry->config = CMOS_ENTRY_RESERVED;
          break;
@@ -758,6 +761,9 @@
       case CMOS_ENTRY_RESERVED:
          return 'r';
 
+      case CMOS_ENTRY_STRING:
+         return 's';
+
       default:
          BUG();
     }
Index: util/nvramtool/README
===================================================================
--- util/nvramtool/README	(revision 364)
+++ util/nvramtool/README	(working copy)
@@ -1,5 +1,3 @@
-$Id: README 3122 2008-03-01 19:06:32Z uwe $
-
 Summary of Operation
 --------------------
 nvramtool is a utility for reading/writing coreboot parameters and
Index: util/nvramtool/layout.c
===================================================================
--- util/nvramtool/layout.c	(revision 364)
+++ util/nvramtool/layout.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * layout.c
- * $Id: layout.c 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
Index: util/nvramtool/cmos_lowlevel.h
===================================================================
--- util/nvramtool/cmos_lowlevel.h	(revision 364)
+++ util/nvramtool/cmos_lowlevel.h	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * cmos_lowlevel.h
- * $Id: cmos_lowlevel.h 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
@@ -33,19 +32,20 @@
 #define NVRAMTOOL_CMOS_LOWLEVEL_H
 
 #include "common.h"
+#include "layout.h"
 
 #define CMOS_AREA_OUT_OF_RANGE (CMOS_RESULT_START + 0)
 #define CMOS_AREA_OVERLAPS_RTC (CMOS_RESULT_START + 1)
 #define CMOS_AREA_TOO_WIDE (CMOS_RESULT_START + 2)
 
-unsigned long long cmos_read (unsigned bit, unsigned length);
-void cmos_write (unsigned bit, unsigned length, unsigned long long value);
+unsigned long long cmos_read (const cmos_entry_t *e);
+void cmos_write (const cmos_entry_t *e, unsigned long long value);
 unsigned char cmos_read_byte (unsigned index);
 void cmos_write_byte (unsigned index, unsigned char value);
 void cmos_read_all (unsigned char data[]);
 void cmos_write_all (unsigned char data[]);
 void set_iopl (int level);
-int verify_cmos_op (unsigned bit, unsigned length);
+int verify_cmos_op (unsigned bit, unsigned length, cmos_entry_config_t config);
 
 #define CMOS_SIZE 256  /* size of CMOS memory in bytes */
 #define CMOS_RTC_AREA_SIZE 14  /* first 14 bytes control real time clock */
Index: util/nvramtool/hexdump.h
===================================================================
--- util/nvramtool/hexdump.h	(revision 364)
+++ util/nvramtool/hexdump.h	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * hexdump.h
- * $Id: hexdump.h 3075 2008-01-25 15:08:37Z uwe $
 \*****************************************************************************/
 
 #ifndef _HEXDUMP_H
Index: util/nvramtool/reg_expr.h
===================================================================
--- util/nvramtool/reg_expr.h	(revision 364)
+++ util/nvramtool/reg_expr.h	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * reg_expr.h
- * $Id: reg_expr.h 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
Index: util/nvramtool/layout_file.h
===================================================================
--- util/nvramtool/layout_file.h	(revision 364)
+++ util/nvramtool/layout_file.h	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * layout_file.h
- * $Id: layout_file.h 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
Index: util/nvramtool/nvramtool.c
===================================================================
--- util/nvramtool/nvramtool.c	(revision 364)
+++ util/nvramtool/nvramtool.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * nvramtool.c
- * $Id: nvramtool.c 3123 2008-03-01 19:07:46Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
@@ -477,6 +476,11 @@
                 e->length);
          break;
 
+      case CMOS_ENTRY_STRING:
+         printf("Parameter %s requires a %u-byte string.\n", name,
+                e->length / 8);
+         break;
+
       case CMOS_ENTRY_RESERVED:
          printf("Parameter %s is reserved.\n", name);
          break;
@@ -570,7 +574,7 @@
 
    /* write the value to nonvolatile RAM */
    set_iopl(3);
-   cmos_write(e->bit, e->length, n);
+   cmos_write(e, n);
    cmos_checksum_write(cmos_checksum_compute());
    set_iopl(0);
    return;
@@ -674,7 +678,7 @@
 
    /* read the value from CMOS */
    set_iopl(3);
-   value = cmos_read(e->bit, e->length);
+   value = cmos_read(e);
    set_iopl(0);
 
    /* display the value */
@@ -703,6 +707,16 @@
 
          break;
 
+      case CMOS_ENTRY_STRING:
+         if (show_name)
+	    printf("%s = %s\n", e->name, (char *)(unsigned long)value);
+	 else
+ 	    printf("%s\n", (char *)(unsigned long)value);
+
+         free((void *)(unsigned long)value);
+
+         break;
+
       case CMOS_ENTRY_RESERVED:
       default:
          BUG();
Index: util/nvramtool/cmos_ops.c
===================================================================
--- util/nvramtool/cmos_ops.c	(revision 364)
+++ util/nvramtool/cmos_ops.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * cmos_ops.c
- * $Id: cmos_ops.c 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
@@ -47,7 +46,7 @@
       /* Access to reserved parameters is not permitted. */
       return CMOS_OP_RESERVED;
 
-   if ((result = verify_cmos_op(e->bit, e->length)) != OK)
+   if ((result = verify_cmos_op(e->bit, e->length, e->config)) != OK)
       return result;
 
    assert(e->length > 0);
@@ -70,6 +69,7 @@
    switch (e->config)
     { case CMOS_ENTRY_ENUM:
       case CMOS_ENTRY_HEX:
+      case CMOS_ENTRY_STRING:
          break;
 
       default:
@@ -92,6 +92,7 @@
  { const cmos_enum_t *q;
    unsigned long long out;
    const char *p;
+   char *memory;
    int negative, result, found_one;
 
    if ((result = prepare_cmos_op_common(e)) != OK)
@@ -139,6 +140,15 @@
 
          break;
 
+      case CMOS_ENTRY_STRING:
+	 if (e->length < (8 * strlen(value_str)))
+	    return CMOS_OP_VALUE_TOO_WIDE;
+	 memory = malloc(e->length / 8);
+         memset(memory, 0, e->length / 8);
+         strcpy(memory, value_str);
+         out = (unsigned long)memory;
+	 break;
+
       default:
          BUG();
     }
Index: util/nvramtool/layout.h
===================================================================
--- util/nvramtool/layout.h	(revision 364)
+++ util/nvramtool/layout.h	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * layout.h
- * $Id: layout.h 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
@@ -49,6 +48,7 @@
 typedef enum
  { CMOS_ENTRY_ENUM,
    CMOS_ENTRY_HEX,
+   CMOS_ENTRY_STRING,
    CMOS_ENTRY_RESERVED
  }
 cmos_entry_config_t;
@@ -59,7 +59,7 @@
    unsigned length;
    cmos_entry_config_t config;
    unsigned config_id;
-   char name[CMOS_MAX_NAME_LENGTH];
+   char name[CMOS_MAX_NAME_LENGTH + 1];
  }
 cmos_entry_t;
 
@@ -69,7 +69,7 @@
 typedef struct
  { unsigned config_id;
    unsigned long long value;
-   char text[CMOS_MAX_TEXT_LENGTH];
+   char text[CMOS_MAX_TEXT_LENGTH + 1];
  }
 cmos_enum_t;
 
Index: util/nvramtool/opts.c
===================================================================
--- util/nvramtool/opts.c	(revision 364)
+++ util/nvramtool/opts.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * opts.c
- * $Id: opts.c 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
Index: util/nvramtool/compute_ip_checksum.c
===================================================================
--- util/nvramtool/compute_ip_checksum.c	(revision 364)
+++ util/nvramtool/compute_ip_checksum.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * compute_ip_checksum.c
- * $Id: compute_ip_checksum.c 3075 2008-01-25 15:08:37Z uwe $
 \*****************************************************************************/
 
 #include <stdint.h>
Index: util/nvramtool/cmos_ops.h
===================================================================
--- util/nvramtool/cmos_ops.h	(revision 364)
+++ util/nvramtool/cmos_ops.h	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * cmos_ops.h
- * $Id: cmos_ops.h 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
Index: util/nvramtool/common.c
===================================================================
--- util/nvramtool/common.c	(revision 364)
+++ util/nvramtool/common.c	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * common.c
- * $Id: common.c 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
@@ -35,7 +34,7 @@
 const char prog_name[] = "nvramtool";
 
 /* version of this program */
-const char prog_version[] = "2.0.1";
+const char prog_version[] = "2.1";
 
 /****************************************************************************
  * get_line_from_file
Index: util/nvramtool/nvramtool.spec
===================================================================
--- util/nvramtool/nvramtool.spec	(revision 364)
+++ util/nvramtool/nvramtool.spec	(working copy)
@@ -1,9 +1,7 @@
 ##
-# $Id: nvramtool.spec 3123 2008-03-01 19:07:46Z uwe $
-##
 
 Name:    nvramtool
-Version: 2.0.1
+Version: 2.1
 Release: 0
 
 Summary: coreboot utility program
Index: util/nvramtool/opts.h
===================================================================
--- util/nvramtool/opts.h	(revision 364)
+++ util/nvramtool/opts.h	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * opts.h
- * $Id: opts.h 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
Index: util/nvramtool/DISCLAIMER
===================================================================
--- util/nvramtool/DISCLAIMER	(revision 364)
+++ util/nvramtool/DISCLAIMER	(working copy)
@@ -1,8 +1,8 @@
 ####################################################################
-# $Id: DISCLAIMER 3122 2008-03-01 19:06:32Z uwe $
-####################################################################
 
 Copyright (C) 2002 The Regents of the University of California.
+Copyright (C) 2008 coresystems GmbH
+
 Produced at the Lawrence Livermore National Laboratory.
 Written by David S. Peterson <dsp@llnl.gov>.
 UCRL-CODE-2003-012
Index: util/nvramtool/Makefile
===================================================================
--- util/nvramtool/Makefile	(revision 364)
+++ util/nvramtool/Makefile	(working copy)
@@ -1,28 +1,43 @@
-# $Id: Makefile 3122 2008-03-01 19:06:32Z uwe $
+#
+# Makefile for nvram utility
+# 
+# (C) 2005-2008 coresystems GmbH
+# written by Stefan Reinauer <stepan@coresystems.de>
+#
 
-PROJECT = nvramtool
-CC = gcc
-CFLAGS = -O2 -W -Wall
-LDFLAGS =
-OBJS = common.o compute_ip_checksum.o hexdump.o cmos_lowlevel.o \
-       reg_expr.o layout.o layout_file.o lbtable.o cmos_ops.o input_file.o \
-       opts.o nvramtool.o
-HEADERS = common.h ip_checksum.h coreboot_tables.h hexdump.h \
-          cmos_lowlevel.h reg_expr.h layout.h layout_file.h lbtable.h \
-          cmos_ops.h input_file.h opts.h
+PROGRAM = nvramtool
 
-all: nvramtool man
+CC      = gcc
+STRIP	= strip
+INSTALL = /usr/bin/install
+PREFIX  = /usr/local
+CFLAGS  = -O2 -g -Wall -W
+#CFLAGS  = -Os -Wall
 
-nvramtool: $(OBJS)
-	$(CC) $(LDFLAGS) -o $@ $(OBJS)
+OBJS =  cmos_lowlevel.o cmos_ops.o common.o compute_ip_checksum.o \
+	hexdump.o input_file.o layout.o layout_file.o lbtable.o   \
+	nvramtool.o opts.o reg_expr.o
 
-man: nvramtool.1.gz
+all: dep $(PROGRAM)
 
-$(OBJS): $(HEADERS)
+$(PROGRAM): $(OBJS)
+	$(CC) -o $(PROGRAM) $(OBJS) $(LDFLAGS)
+	$(STRIP) $(STRIP_ARGS) $(PROGRAM)
 
-nvramtool.1.gz: nvramtool.1
-	gzip -c --best nvramtool.1 > nvramtool.1.gz
-
 clean:
-	rm -f *.o nvramtool nvramtool.1.gz
+	rm -f $(PROGRAM) *.o
 
+distclean: clean
+	rm -f .dependencies
+
+dep:
+	@$(CC) -MM *.c > .dependencies
+
+install: $(PROGRAM)
+	$(INSTALL) $(PROGRAM) $(PREFIX)/sbin
+	mkdir -p $(PREFIX)/share/man/man1
+	$(INSTALL) $(PROGRAM).1 $(PREFIX)/share/man/man1
+
+.PHONY: all clean distclean dep
+
+-include .dependencies
Index: util/nvramtool/common.h
===================================================================
--- util/nvramtool/common.h	(revision 364)
+++ util/nvramtool/common.h	(working copy)
@@ -1,6 +1,5 @@
 /*****************************************************************************\
  * common.h
- * $Id: common.h 3122 2008-03-01 19:06:32Z uwe $
  *****************************************************************************
  *  Copyright (C) 2002-2005 The Regents of the University of California.
  *  Produced at the Lawrence Livermore National Laboratory.
